package MT::Plugin::Mediawiki;

use strict;

use MT;
use base qw( MT::Plugin );
our $VERSION = 0.1;

use Text::MediawikiFormat 'wikiformat';

my $plugin = __PACKAGE__->new({
                               id => 'Mediawiki',
                               key => 'Mediawiki',
                               name => 'Mediawiki',
                               description => '<MT_TRANS phrase="A text-to-HTML formatting plugin (Mediawiki Style)">',
                               author_name => '<MT_TRANS phrase="KAWABATA Kazumichi">',
                               author_link => 'http://haro.jp/',
                               version => $VERSION,
                               l10n_class => 'Mediawiki::L10N',
                              });
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
                       text_filters => {
                                        mediawiki => {
                                                      label => 'Mediawiki',
                                                      code => \&_to_html,
                                                      docs => 'http://commons.wikimedia.org/wiki/File:Cheatsheet-en.png',
                                                   },
                                       },
#                       callbacks => {
#                                     'MT::App::CMS::template_source.archetype_editor' => \&_archetype_editor,
#                                   },
                      });


}

sub _to_html {
    my ($str, $ctx) = @_;

    # to_utf;
    require MT::I18N;
    $str = MT::I18N::encode_text( $str, MT->instance->config->PublishCharset, 'utf-8' );

    # to_html
    utf8::decode($str);
    my $html = wikiformat($str);
    utf8::encode($html);

    # to_publishcharset
    $html = MT::I18N::encode_text( $html, 'utf-8', MT->instance->config->PublishCharset );
    $html;
}

#sub _archetype_editor {
#    my ($eh, $app, $tmpl) = @_;
#
#    $$tmpl =~ s|(<script .*archetype_editor.js.*></script>)|$1<script type="text/javascript" src="<mt:var name="static_uri">plugins/HikiDoc/archetype_editor.js"></script>|;
#}



=head1 NAME

MT::Plugin::Mediawiki - A text-to-HTML formatting plugin (Mediawiki Style) for Movavle Type/MTOS 4.2x .

=head1 AUTHOR

This release was made by KAWABATA, Kazumichi (Higemaru) E<lt>kawabata@cpan.orgE<gt> http://haro.jp/

=head1 COPYRIGHT AND LICENSE

This library 'MT::Plugin::Mediawiki' is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

Copyright (C) 2010- KAWABATA, Kazumichi (Higemaru) E<lt>kawabata@cpan.orgE<gt>

=cut

1;
